Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(229)

Unified Diff: content/browser/renderer_host/render_process_host_impl.cc

Issue 2381493003: Move ViewMsg_New to mojom (Closed)
Patch Set: . Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/render_process_host_impl.cc
diff --git a/content/browser/renderer_host/render_process_host_impl.cc b/content/browser/renderer_host/render_process_host_impl.cc
index 86542396b12f3788cac8e74a7c60eb6dc33552e5..34c1128304cb726c5a65401ce6dada0f794c57d8 100644
--- a/content/browser/renderer_host/render_process_host_impl.cc
+++ b/content/browser/renderer_host/render_process_host_impl.cc
@@ -866,9 +866,10 @@ bool RenderProcessHostImpl::Init() {
if (channel_)
return true;
// Ensure that the RouteProvider proxy is re-initialized on next access since
// it's associated with a specific Channel instance.
remote_route_provider_.reset();
+ renderer_interface_.reset();
base::CommandLine::StringType renderer_prefix;
// A command prefix is something prepended to the command line of the spawned
@@ -1444,6 +1445,14 @@ mojom::RouteProvider* RenderProcessHostImpl::GetRemoteRouteProvider() {
return remote_route_provider_.get();
}
+mojom::Renderer* RenderProcessHostImpl::GetRendererInterface() {
+ if (!renderer_interface_) {
+ DCHECK(channel_);
+ channel_->GetRemoteAssociatedInterface(&renderer_interface_);
+ }
+ return renderer_interface_.get();
+}
+
void RenderProcessHostImpl::AddRoute(int32_t routing_id,
IPC::Listener* listener) {
CHECK(!listeners_.Lookup(routing_id)) << "Found Routing ID Conflict: "
@@ -866,9 +866,10 @@ bool RenderProcessHostImpl::Init() {
if (channel_)
return true;
- // Ensure that the RouteProvider proxy is re-initialized on next access since
- // it's associated with a specific Channel instance.
+ // Ensure that the remote associated interfaces are re-initialized on next
+ // access since they're associated with a specific Channel instance.
remote_route_provider_.reset();

Powered by Google App Engine
This is Rietveld 408576698